<?php

/**
 * Fired during plugin activation
 *
 * @link       https://www.cloudoos.com
 * @since      1.0.0
 *
 * @package    Distrimedia_Integration
 * @subpackage Distrimedia_Integration/includes
 */

/**
 * Fired during plugin activation.
 *
 * This class defines all code necessary to run during the plugin's activation.
 *
 * @since      1.0.0
 * @package    Distrimedia_Integration
 * @subpackage Distrimedia_Integration/includes
 * @author     Cloudoos <support@cloudoos.com>
 */
class Distrimedia_Integration_Activator {

	/**
	 * Short Description. (use period)
	 *
	 * Long Description.
	 *
	 * @since    1.0.0
	 */
	public static function activate() {
		self::createOrdersTable();
		self::createOrderLogsTable();
		self::createProductsTable();
	}

	/**
	 * Create a new table for managing distrimedia orders
	 */
	private static function createOrdersTable() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE IF NOT EXISTS `{$wpdb->base_prefix}dm_orders` (
				  order_id bigint(20) UNSIGNED NOT NULL UNIQUE,
				  dm_order_id varchar(100) NOT NULL UNIQUE,
				  dm_status text DEFAULT NULL,
				  created_at datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
				  PRIMARY KEY  (order_id)
				) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}

	/**
	 * Drop this table upon uninstall
	 */
	private static function createOrderLogsTable() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE IF NOT EXISTS `{$wpdb->base_prefix}dm_order_logs` (
				  id int NOT NULL auto_increment,
				  order_id bigint(20) UNSIGNED NOT NULL,
				  log_type INT(1) NOT NULL DEFAULT 1,
				  local_method TEXT,
				  message TEXT,
				  created_at datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
				  PRIMARY KEY  (id)
				) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}

	private static function createProductsTable() {
		global $wpdb;
		$charset_collate = $wpdb->get_charset_collate();

		$sql = "CREATE TABLE IF NOT EXISTS `{$wpdb->base_prefix}dm_products` (
				  product_id bigint(20) UNSIGNED NOT NULL UNIQUE,
				  ean VARCHAR(200) NOT NULL,
				  inventory TEXT,
				  synced_at datetime NOT NULL DEFAULT CURRENT_TIMESTAMP,
				  PRIMARY KEY  (product_id)
				) $charset_collate;";

		require_once( ABSPATH . 'wp-admin/includes/upgrade.php' );
		dbDelta( $sql );
	}

}
