<?php

class Distrimedia_Integration_Bpost {

	protected $points = false;

	protected $bpostType = 15;

	protected $accountNum = false;
	protected $baseUrl = false;
	protected $googleApi = false;
	protected $lang = 'EN';
	protected $apiTimeout = 300;

	public function __construct() {
		$this->accountNum = get_option( 'wc_settings_tab_distrimedia_bpost_account', false );
		$this->googleApi  = get_option( 'wc_settings_tab_distrimedia_google_api', false );
		$this->baseUrl    = get_option( 'wc_settings_tab_distrimedia_bpost_url', 'https://pudo.bpost.be/Locator' );
		if ( defined( 'ICL_LANGUAGE_CODE' ) ) {
			$this->lang = ICL_LANGUAGE_CODE;
		}
	}

	public function get_bpost_station( $id ) {
		$bposts = $this->get_bpost_points();

		foreach ( $bposts as $point ) {
			if ( $point->Id == $id ) {
				return $point;
			}
		}

		return false;
	}

	/**
	 * Method for getting latest BPost points
	 * @return array|bool|mixed
	 */
	public function get_bpost_points() {
		if ( $this->points ) {
			$this->points;
		}

		//Check if we have file available locally
		$pointsFile  = wp_get_upload_dir()['basedir'] . '/bpost-points.xml';
		$bpostPoints = @file_get_contents( $pointsFile );

		//If we have nothing in cache
		if ( ! $bpostPoints && $this->accountNum ) {
			$bpostAccount = $this->accountNum;
			$bpostUrl     = $this->baseUrl;
			$type         = $this->bpostType;
			$lang         = $this->lang;
			$args         = array(
				'timeout'   => $this->apiTimeout,
				'sslverify' => false
			);

			$response = wp_remote_get( "$bpostUrl?Function=getallservicepoints&Account=$bpostAccount&Language=$lang&Country=BE&Type=$type", $args );
			if ( ! is_wp_error( $response ) && $response['body'] ) {
				$bpostPoints = $response['body'];
			}
		}

		if ( $responseXml = simplexml_load_string( $bpostPoints ) ) {
			$json        = json_encode( $responseXml );
			$responseXml = json_decode( $json );

			$bpostPoints = $responseXml->PickupPointList->Point;
		}

		return $this->points = $bpostPoints;
	}

	public function download_bpost_local() {
		$bpostAccount = $this->accountNum;

		if ( ! $bpostAccount ) {
			return false;
		}

		$bpostUrl = $this->baseUrl;

		require_once( ABSPATH . "wp-admin" . '/includes/file.php' );
		$permfile = wp_get_upload_dir()['basedir'] . '/bpost-points.xml';
		$type     = $this->bpostType;

		$lang    = $this->lang;
		$tmpfile = download_url( "$bpostUrl?Function=getallservicepoints&Account=$bpostAccount&Language=$lang&Country=BE&Type=$type", $this->apiTimeout );
		if ( ! is_wp_error( $tmpfile ) ) {
			copy( $tmpfile, $permfile );
			unlink( $tmpfile );
		}

		return true;
	}

	public function get_google_api() {
		return $this->googleApi;
	}

	public function has_shipping_method($targets, $method) {

		if(is_array($targets)) {
			foreach ($targets as $target) {
				if(strpos($target, $method) !== false) return true;
			}

			return false;
		}

		if($targets == $method) {
			return true;
		}

		return strpos($targets, $method);

	}

}
