<?php

class Distrimedia_Integration_Client {

	//private $url = 'http://devewms.distrimedia.be:8080'; // Test
	//private $url = 'http://ewms.distrimedia.be:8080'; // Production
	private $url = ''; // url
	private $soapPass = false;
	private $shop = false;
	
	/**  
	* set free shipping settings start here
	* vaibhav 06-02-2021 
	*/
	function __construct() {
        $this->url = get_option('wc_settings_tab_distrimedia_environment');
    }
    /**  
	* end 
	*/

	/**
	 * This helper will be used to communicate anything to distrimedia
	 * @param $action
	 * @param $param
	 *
	 * @return array|bool|SimpleXMLElement|WP_Error
	 */
	public function call($action, $param) {
		if(!get_option('wc_settings_tab_distrimedia_valid_license', true ) && !strpos(get_site_url(), '.test')) {
			error_log('Distrimedia Call failed due to license not being valid');
			return false;
		}

		$this->shop = get_option( 'wc_settings_tab_distrimedia_id', true );
		$this->soapPass = get_option( 'wc_settings_tab_distrimedia_pass', true );

		if(!$this->shop || !$this->soapPass) {
			return false;
		}

		$this->basicConfig($param);

		$xml = $this->arrayToXml($param);
		$response = wp_remote_post( $this->url, array(
				'headers'     => array(
					'Content-Type'  =>  'text/xml',
					'SOAPAction'    =>  $action
				),
				'timeout'   =>  300,
				'data_format'   =>   'body',
				'body'        => $xml
			)
		);

		error_log( 'Request Body: ' . $xml );

		if ( is_wp_error( $response ) ) {
			$error_message = $response->get_error_message();
			echo "Something went wrong: $error_message";
			return false;
		} else {
			$responseXml = simplexml_load_string($response['body']);
		}

		$response = $responseXml->children('soap', true)->children()->SoapRequestResult;

		error_log( 'Response Body: ' . (string)$response->asXML() );

		return $response;
	}

	/**
	 * Setup basic config before call
	 * @param $param
	 */
	private function basicConfig(&$param) {
		$config = array(
			'WebshopCode'   =>  $this->shop,
			'SoapPassword'  =>  $this->soapPass,
		);
		$mergedArrays['soap:soap:Body'] = array_merge($config, $param);

		$param = $mergedArrays;
	}

	/**
	 * Helper to convert given array into XML for SOAP requests
	 *
	 * @param $array
	 * @param null $rootElement
	 * @param null $xml
	 *
	 * @return mixed
	 */
	private function arrayToXml($array, $rootElement = null, $xml = null) {
		$_xml = $xml;

		// If there is no Root Element then insert root
		if ($_xml === null) {
			$_xml = new SimpleXMLElement($rootElement !== null ? $rootElement : '<Envelope xmlns:soap="http://schemas.xmlsoap.org/soap/envelope/" />');
			$_xml->addAttribute("xmlns:xsi", "http://www.w3.org/2001/XMLSchema-instance");
			$_xml->addAttribute("xmlns:xsd", "http://www.w3.org/2001/XMLSchema");
		}

		// Visit all key value pair
		foreach ($array as $k => $v) {

			if(strpos($k, '-dup-') !== false) {
				$k = explode('-', $k)[0];
			}
			// If there is nested array then
			if (is_array($v)) {

				// Call function for nested array
				$this->arrayToXml($v, $k, $_xml->addChild($k));
			}

			else {
				// Simply add child element.
				$_xml->addChild($k, $v);
			}
		}

		return $_xml->asXML();
	}
}