<?php

if ( ! class_exists( 'Distrimedia_Integration_Home' ) ) {
//	class Distrimedia_Integration_Home extends WC_Shipping_Method {
	class Distrimedia_Integration_Home extends WC_Shipping_Flat_Rate {
		public function __construct( $instance_id = 0 ) {
			$this->id                 = 'distrimedia_home';
			$this->instance_id        = absint( $instance_id );
			$this->method_title       = __( 'Standard (Distrimedia)', 'distrimedia-integration' );
			$this->method_description = __( 'Home or Office Delivery', 'distrimedia-integration' );
			$this->supports           = array(
				'shipping-zones',
				'instance-settings',
				'instance-settings-modal',
			);
			$this->enabled = isset( $this->settings['enabled'] ) ? $this->settings['enabled'] : 'no';

			$this->init();

			add_action( 'woocommerce_update_options_shipping_' . $this->id, array(
				$this,
				'process_admin_options'
			) );
		}

		/**
		 * Init your settings
		 *
		 * @access public
		 * @return void
		 */
		function init() {
			// Load the settings API
			$this->instance_form_fields = $this->init_form_fields(); // This is part of the settings API. Override the method to add your own settings
			$this->init_settings(); // This is part of the settings API. Loads settings you previously init.

			// Define user set variables.
			$this->enabled              = $this->get_option( 'enabled' );
			$this->title                = $this->get_option( 'title' );
			$this->tax_status           = $this->get_option( 'tax_status' );
			$this->cost                 = $this->get_option( 'cost' );
			$this->type                 = $this->get_option( 'type', 'class' );
			
			/**  
			* set free shipping settings start here
			* vaibhav 06-02-2021 
			*/
            $this->min_amount   = $this->get_option( 'min_amount', 0 );
            $this->requires   = $this->get_option( 'requires' );
            $this->ignore_discounts   = $this->get_option( 'ignore_discounts' );
            /**  
			* end
			*/
            
            
			// Save settings in admin if you have any defined
//			add_action( 'woocommerce_update_options_shipping_' . $this->id, array(
//				$this,
//				'process_admin_options'
//			) );
		}

		public function init_form_fields() {
			$cost_desc = __( 'Enter a cost (excl. tax) or sum, e.g. <code>10.00 * [qty]</code>.', 'woocommerce' ) . '<br/><br/>' . __( 'Use <code>[qty]</code> for the number of items, <br/><code>[cost]</code> for the total cost of items, and <code>[fee percent="10" min_fee="20" max_fee=""]</code> for percentage based fees.', 'woocommerce' );

			$settings = array(
				'title'      => array(
					'title'       => __( 'Method title', 'woocommerce' ),
					'type'        => 'text',
					'description' => __( 'This controls the title which the user sees during checkout.', 'woocommerce' ),
					'default'     => __( $this->method_title, 'woocommerce' ),
					'desc_tip'    => true,
				),
				'tax_status' => array(
					'title'   => __( 'Tax status', 'woocommerce' ),
					'type'    => 'select',
					'class'   => 'wc-enhanced-select',
					'default' => 'taxable',
					'options' => array(
						'taxable' => __( 'Taxable', 'woocommerce' ),
						'none'    => _x( 'None', 'Tax status', 'woocommerce' ),
					),
				),
				'cost'       => array(
					'title'             => __( 'Cost', 'woocommerce' ),
					'type'              => 'text',
					'placeholder'       => '',
					'description'       => $cost_desc,
					'default'           => '0',
					'desc_tip'          => true,
					'sanitize_callback' => array( $this, 'sanitize_cost' ),
				),
			);

			$shipping_classes = WC()->shipping()->get_shipping_classes();

			if ( ! empty( $shipping_classes ) ) {
				$settings['class_costs'] = array(
					'title'       => __( 'Shipping class costs', 'woocommerce' ),
					'type'        => 'title',
					'default'     => '',
					/* translators: %s: URL for link. */
					'description' => sprintf( __( 'These costs can optionally be added based on the <a href="%s">product shipping class</a>.', 'woocommerce' ), admin_url( 'admin.php?page=wc-settings&tab=shipping&section=classes' ) ),
				);
				foreach ( $shipping_classes as $shipping_class ) {
					if ( ! isset( $shipping_class->term_id ) ) {
						continue;
					}
					$settings[ 'class_cost_' . $shipping_class->term_id ] = array(
						/* translators: %s: shipping class name */
						'title'             => sprintf( __( '"%s" shipping class cost', 'woocommerce' ), esc_html( $shipping_class->name ) ),
						'type'              => 'text',
						'placeholder'       => __( 'N/A', 'woocommerce' ),
						'description'       => $cost_desc,
						'default'           => $this->get_option( 'class_cost_' . $shipping_class->slug ), // Before 2.5.0, we used slug here which caused issues with long setting names.
						'desc_tip'          => true,
						'sanitize_callback' => array( $this, 'sanitize_cost' ),
					);
				}

				$settings['no_class_cost'] = array(
					'title'             => __( 'No shipping class cost', 'woocommerce' ),
					'type'              => 'text',
					'placeholder'       => __( 'N/A', 'woocommerce' ),
					'description'       => $cost_desc,
					'default'           => '',
					'desc_tip'          => true,
					'sanitize_callback' => array( $this, 'sanitize_cost' ),
				);

				$settings['type'] = array(
					'title'   => __( 'Calculation type', 'woocommerce' ),
					'type'    => 'select',
					'class'   => 'wc-enhanced-select',
					'default' => 'class',
					'options' => array(
						'class' => __( 'Per class: Charge shipping for each shipping class individually', 'woocommerce' ),
						'order' => __( 'Per order: Charge shipping for the most expensive shipping class', 'woocommerce' ),
					),
				);
				
				/**  
    			* set free shipping settings start here
    			* vaibhav 06-02-2021 
    			*/
				$settings['requires'] = array(
    				'title'   => __( 'Free shipping requires...', 'woocommerce' ),
    				'type'    => 'select',
    				'class'   => 'wc-enhanced-select',
    				'default' => '',
    				'options' => array(
    					''           => __( 'N/A', 'woocommerce' ),
    					'coupon'     => __( 'A valid free shipping coupon', 'woocommerce' ),
    					'min_amount' => __( 'A minimum order amount', 'woocommerce' ),
    					'either'     => __( 'A minimum order amount OR a coupon', 'woocommerce' ),
    					'both'       => __( 'A minimum order amount AND a coupon', 'woocommerce' ),
    				),
    			);
    			
    			$settings['min_amount'] = array(
    				'title'       => __( 'Minimum order amount', 'woocommerce' ),
    				'type'        => 'price',
    				'placeholder' => wc_format_localized_price( 0 ),
    				'description' => __( 'Users will need to spend this amount to get free shipping (if enabled above).', 'woocommerce' ),
    				'default'     => '0',
    				'desc_tip'    => true,
    			);
    			
    			$settings['ignore_discounts'] = array(
    				'title'       => __( 'Coupons discounts', 'woocommerce' ),
    				'label'       => __( 'Apply minimum order rule before coupon discount', 'woocommerce' ),
    				'type'        => 'checkbox',
    				'description' => __( 'If checked, free shipping would be available based on pre-discount order amount.', 'woocommerce' ),
    				'default'     => 'no',
    				'desc_tip'    => true,
    			);
    			/**  
    			* end
    			*/
			}

			return $settings;
		}

		/**
		 * calculate_shipping function.
		 *
		 * @access public
		 *
		 * @param mixed $package
		 *
		 * @return void
		 */
		 
		 /**  
        * set free shipping settings start here
        * vaibhav 06-02-2021 
        */
		 public function calculate_shipping( $package = array() ){
    		
    		$is_available         = false;
    		$has_coupon         = false;
    		$has_met_min_amount = false;
    
    		if ( in_array( $this->requires, array( 'coupon', 'either', 'both' ), true ) ) {
    			$coupons = WC()->cart->get_coupons();
    
    			if ( $coupons ) {
    				foreach ( $coupons as $code => $coupon ) {
    					if ( $coupon->is_valid() && $coupon->get_free_shipping() ) {
    						$has_coupon = true;
    						break;
    					}
    				}
    			}
    		}
    
    		if ( in_array( $this->requires, array( 'min_amount', 'either', 'both' ), true ) ) {
    			$total = WC()->cart->get_displayed_subtotal();
    
    			if ( WC()->cart->display_prices_including_tax() ) {
    				$total = $total - WC()->cart->get_discount_tax();
    			}
    
    			if ( 'no' === $this->ignore_discounts ) {
    				$total = $total - WC()->cart->get_discount_total();
    			}
    
    			$total = round( $total, wc_get_price_decimals() );
    
    			if ( $total >= $this->min_amount ) {
    				$has_met_min_amount = true;
    			}
    		}
    
    		switch ( $this->requires ) {
    			case 'min_amount':
    				$is_available = $has_met_min_amount;
    				break;
    			case 'coupon':
    				$is_available = $has_coupon;
    				break;
    			case 'both':
    				$is_available = $has_met_min_amount && $has_coupon;
    				break;
    			case 'either':
    				$is_available = $has_met_min_amount || $has_coupon;
    				break;
    			default:
    				$is_available = true;
    				break;
    		}
			
    		if ( $is_available==true ) {
                $rate = array(
                    'id' => $this->id,
                    'label' => $this->title.' FREE SHIPMENT',
                    'cost' => 0
                );
                $this->add_rate( $rate );
            }else {
                $rate = array(
                    'id' => $this->id,
                    'label' => $this->title,
                    'cost' => $this->cost
                );
                $this->add_rate( $rate );
            }
            
        }
        /**  
		* end
		*/

//		public function calculate_shipping( $package = array() ) {
//			$rate = array(
//				'id'       => $this->id,
//				'label'    => $this->title,
//				'cost'     => 0.00,
//				'calc_tax' => 'per_order'
//			);
//
//			// Register the rate
//			$this->add_rate( $rate );
//
//		}
	}
}
